@@ -1,7 +1,7 @@
 from .classes import CreateGroupVars, MorphConfig
 from .contentPack_processing import (
     contentPack_file_processor,
-    contentPack_implementation,
+    contentPack_implementation
 )
 from .cypher import cypherCreate
 from .file_handler import imageResizer, un_zipFiles
@@ -31,3 +31,4 @@ from .whitelabel import (
 from .wiki import addWikiEntry
 from .yaml_validator import validate
 from .initapp import initSetup
+from .init_contentPack import contentPack_initSetup
