@@ -1,8 +1,8 @@
-import json
+#import json
 import os
 from configparser import ConfigParser
 
-import requests
+#import requests
 import yaml
 
 
@@ -25,19 +25,26 @@ class MorphConfig(object):
         #self.ROOT_USERNAME = configur.get("DEFAULT", "ROOT_USERNAME")
         #self.ROOT_PASSWORD = configur.get("DEFAULT", "ROOT_PASSWORD")
 
-        def bearer():
+       # def bearer():
             #  logger = morph_log.get_logger('getg')
-            url = (
-                self.baseURL
-                + "/oauth/token?grant_type=password&scope=write&client_id=morph-api"
-            )
-            payload = {"username": self.ADMIN_USERNAME, "password": self.ADMIN_PASSWORD}
-            result = requests.request("POST", url, verify=False, data=payload)
-            jsonDump = json.loads(result.text)
-            # logger.debug(jsonDump["access_token"])
-            return jsonDump["access_token"]
-       # try: 
-        self.bearer = bearer()
+        #    url = (
+        #        self.baseURL
+        #        + "/oauth/token?grant_type=password&scope=write&client_id=morph-api"
+        #    )
+        #    payload = {"username": self.ADMIN_USERNAME, "password": self.ADMIN_PASSWORD}
+        #    result = requests.request("POST", url, verify=False, data=payload)
+        #    jsonDump = json.loads(result.text)
+        #    # logger.debug(jsonDump["access_token"])
+        #    return jsonDump["access_token"]
+        #try: 
+         #   """
+         #   if environment variable is set to initial then skip this.  
+#
+ #           else if environment variable is set to anything else then set the bearer token. 
+#
+ #           """
+
+        #    self.bearer = bearer()
         #except Exception as e:
         #    print('Could not set the bearer token')
         #    print('setting to blank') 
@@ -49,17 +56,20 @@ class MorphConfig(object):
         return False
 
     def header_appJson(self):
+        bearer = os.environ.get("bearerToken")
         return {
             "Content-Type": "application/json",
-            "Authorization": "Bearer " + self.bearer,
+            "Authorization": "Bearer " + bearer,
         }
     def initHeader(self):
         return {"Content-Type": "application/json"}
     def imageWhiteLabel(self):
-        return {"Authorization": "Bearer " + self.bearer}
+        bearer = os.environ.get("bearerToken")
+        return {"Authorization": "Bearer " + bearer}
 
     def authBearer_noContent(self):
-        return {"Authorization": "Bearer " + self.bearer}
+        bearer = os.environ.get("bearerToken")
+        return {"Authorization": "Bearer " + bearer}
 
     def createGroups(self):
         # group.createGroups()
