@@ -2,7 +2,7 @@ import fnmatch
 import glob
 import time
 from configparser import ConfigParser
-
+import os
 import yaml
 
 from . import (
@@ -16,7 +16,8 @@ from . import (
     tasks,
     users,
     whitelabel,
-    wiki
+    wiki,
+    getBearerToken
 )
 
 
@@ -38,14 +39,15 @@ def contentPack_implementation(contentPackSelection):
     # contentPack = contentPackSelection
     # Set Variables
     baseURL = configur.get("DEFAULT", "BASE_URL")
-    # ADMIN_USERNAME = configur.get("DEFAULT", "ADMIN_USERNAME")
-    # ADMIN_PASSWORD = configur.get("DEFAULT", "ADMIN_PASSWORD")
+    ADMIN_USERNAME = configur.get("DEFAULT", "ADMIN_USERNAME")
+    ADMIN_PASSWORD = configur.get("DEFAULT", "ADMIN_PASSWORD")
 
-    # bearerToken = getBearerToken.bearerToken(baseURL, ADMIN_USERNAME, ADMIN_PASSWORD)
+    bearerToken = getBearerToken.bearerToken(baseURL, ADMIN_USERNAME, ADMIN_PASSWORD)
+    os.environ["bearerToken"] = bearerToken
     # Logging
     logger = morph_log.get_logger("cp_impl")
     # Process content pack yaml files.
-    files_inContentPack = glob.glob(contentPackSelection + "/*")
+    files_inContentPack = sorted(glob.glob(contentPackSelection + "/*"))
     for file in files_inContentPack:
         if file.endswith(".yaml") and file != contentPackSelection + "/version.yaml" and file != contentPackSelection + "/initial.yaml":
             yaml_file = file
@@ -59,11 +61,7 @@ def contentPack_implementation(contentPackSelection):
             logger.info("Morpheus Component Detected: " + morpheusComponent)
             logger.info("Verifying Yaml: " + yaml_file)
             file_handler.verify_yaml_structure_helper(morpheusComponent, yaml_file)
-            if morpheusComponent in ["users", "user"]:
-                logger.info("Adding Users")
-                users.createUser(yaml_file)
-                logger.info("Completed: Users")
-            elif morpheusComponent in ["groups", "group"]:
+            if morpheusComponent in ["groups", "group"]:
                 logger.info("Adding Groups")
                 group.createGroups(yaml_file)
                 logger.info("Completed: Groups")
@@ -75,6 +73,10 @@ def contentPack_implementation(contentPackSelection):
                 logger.info("Adding Roles")
                 role.genericRoleCreate(yaml_file)
                 logger.info("Completed: Roles")
+            elif morpheusComponent in ["users", "user"]:
+                logger.info("Adding Users")
+                users.createUser(yaml_file)
+                logger.info("Completed: Users")
             elif morpheusComponent in ["cyphers", "cypher"]:
                 logger.info("Adding Cyphers")
                 cypher.cypherCreate(baseURL, yaml_file)
